<template>
  <!-- <div v-if="isShow">
    <gree-picker
      class="svst-picker"
      :class="{ onSetTemF: this.TemUn }"
      ref="svst-picker"
      v-model="isShow"
      :title="$language('svst.title')"
      :data="silderList"
      :describe="svstText"
      :default-index="currentIndex"
      ok-text
      cancel-text
      @confirm="confirmHandler"
    >
    </gree-picker>
  </div> -->
  <gree-popup class="svst-picker" v-model="isShowPicker" position="bottom" get-container="body" safe-area-inset-bottom @hide="onHide">
    <gree-picker
      ref="picker"
      :class="{ onSetTemF: this.TemUn }"
      :cancel-button-text="$language('popup.cancel')"
      :confirm-button-text="$language('popup.confirm')"
      :columns="silderList"
      :default-value="defaultValue"
      @cancel="onCancel"
      @confirm="onConfirm"
    >
      <div class="custom-picker__title" slot="title">
        <p>{{ $language('svst.title') }}</p>
        <small>{{ svstText }}</small>
      </div>
    </gree-picker>
  </gree-popup>
</template>

<script>
import { Picker, Popup } from 'gree-ui';
import { mapState, mapMutations, mapGetters } from 'vuex';
import { mapActions } from 'vuex';
import temUnChange from '@/mixins/tem';

export default {
  name: 'SvStPicker',
  components: {
    [Popup.name]: Popup,
    [Picker.name]: Picker
  },
  mixins: [temUnChange],
  data() {
    return {
      defaultValue: 0,
      isShowPicker: false,
      coolMod: [1],
      dryMod: [2],
      // heatMod: [4, 6, 7],
      heatMod: [4],
      fastHeat: [6],
      heating: [7]
    };
  },
  computed: {
    ...mapState('control', {
      SvStPopup: state => state.popup.SvStPopup,
      SvSt: state => state.dataObject.SvSt,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      CoolSvStTemMinD: state => state.dataObject.CoolSvStTemMinD || 20,
      HumiSvStTemMinD: state => state.dataObject.HumiSvStTemMinD || 18,
      HeatSvStTemMaxD: state => state.dataObject.HeatSvStTemMaxD || 18,
      Heat3DSvStTemMaxD: state => state.dataObject.Heat3DSvStTemMaxD || 18,
      Heat2SvStTemMaxD: state => state.dataObject.Heat2SvStTemMaxD || 18,
      HumiEnable: state => state.dataObject.HumiEnable,
      TemUn: state => state.dataObject.TemUn
    }),
    ...mapGetters([
      'modTextKey',
      'modIdentifier',
      'modCurrentStatusName',
      'temSetVal',
      'temSetJson',
      'temMinVal',
      'temMaxVal',
      'spModCurrentStatusName',
      'spModIdentifier'
    ]),
    ...mapGetters('machine', ['statusMap']),
    // 当前模式的status
    modStatus() {
      return this.statusMap[this.modIdentifier];
    },
    // 当前特殊模式的status
    spModStatus() {
      return this.statusMap[this.spModIdentifier];
    },
    // 制热和制冷不一样的配置
    silderType() {
      const value =
        (this.modStatus ? Number(this.modStatus.status.value) : undefined) || (this.spModStatus ? Number(this.spModStatus.status.value) : undefined);
      let result = {};
      if (this.coolMod.includes(value)) {
        result = {
          type: 'cool',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'CoolSvStTemMin'
        };
      } else if (this.dryMod.includes(value)) {
        result = {
          type: 'dry',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'HumiSvStTemMin'
        };
      } else if (this.heatMod.includes(value)) {
        result = {
          type: 'heat',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'HeatSvStTemMax'
        };
      } else if (this.fastHeat.includes(value)) {
        result = {
          type: 'spHeatFast',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'Heat3DSvStTemMax'
        };
      } else if (this.heating.includes(value)) {
        result = {
          type: 'spHeating',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'Heat2SvStTemMax'
        };
      } else {
        result = {
          type: 'cool',
          min: 16,
          max: 30,
          minF: 61,
          maxF: 86,
          default: 18,
          json: 'CoolSvStTemMin'
        };
      }
      return result;
    },
    // 文案
    svstTextList() {
      const modArr = ['status_1', 'status_6', 'status_7'];
      if (modArr.includes(this.modCurrentStatusName))
        return [this.$language('svst.text-tip1'), '，' + this.$language('svst.text-tip2'), this.$language('svst.text-tip3')];
      return [this.$language('svst.text-tip1'), '，' + this.$language('svst.text-tip2'), this.$language('svst.text-tip4')];
    },
    modText() {
      return this.$language(this.modTextKey);
    },
    svstText() {
      return this.svstTextList[0] + this.modText + this.svstTextList[1] + this.modText + this.svstTextList[2];
    },
    // 滑轮配置
    silderList() {
      if (!this.silderType.type) return [[]];
      const { min, max, minF, maxF } = this.silderType;
      let silderMin = this.TemUn ? minF : min;
      let silderMax = this.TemUn ? maxF : max;
      const result = [];
      for (let i = silderMin; i <= silderMax; i += 1) {
        result.push(
          // text: `${i}`,
          // value: i
          i
        );
      }
      return result;
    }
    // 当前设置温度
    // currentIndex() {
    //   const json = this.TemUn ? this.silderType.json + 'D' : this.silderType.json;
    //   // return !this.TemUn ? [(this[json] || 18) - 16] : [(this.tempC2F(`${this[json]}`) || 65) - 61];
    //   return this.TemUn ? [(this[json] || 65) - 61] : [(this[json] || 18) - 16];
    // }
  },
  watch: {
    SvStPopup(val) {
      this.isShowPicker = val;
    },
    temMinVal(newVal) {
      if (!this.TemUn && this.SvSt) {
        // 摄氏度时不变
        newVal > this.temSetVal &&
          this.stateMatchineInterFace({
            data: { [this.temSetJson]: newVal }
          });
      } else if (this.TemUn && this.SvSt) {
        // 华氏度时发的温度要转成摄氏度值
        newVal > this.tempC2F(this.temSetVal, this.TemRec) &&
          this.stateMatchineInterFace({
            data: {
              [this.temSetJson]: this.tempF2C(newVal)[1],
              TemRec: this.tempF2C(newVal)[3]
            }
          });
      }
    },
    temMaxVal(newVal) {
      if (!this.TemUn && this.SvSt) {
        // 摄氏度时不变
        newVal < this.temSetVal &&
          this.stateMatchineInterFace({
            data: { [this.temSetJson]: newVal }
          });
      } else if (this.TemUn && this.SvSt) {
        // 华氏度时发的温度要转成摄氏度值
        newVal < this.tempC2F(this.temSetVal, this.TemRec) &&
          this.stateMatchineInterFace({
            data: {
              [this.temSetJson]: this.tempF2C(newVal)[1],
              TemRec: this.tempF2C(newVal)[3]
            }
          });
      }
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE'
    }),
    onConfirm() {
      this.SetPopup({ SvStPopup: false });
      try {
        const value = this.$refs['picker'].getValues()[0];
        if (this.TemUn) {
          //华氏度时发送的节能字段与摄氏度时的字段不同
          const { json } = this.silderType;
          this.stateMatchineInterFace({
            data: {
              [[json] + 'D']: this.tempF2C(value)[0] * 10,
              SvSt: 1
            }
          });
          this.setDataObject({ [[json] + 'D']: value });
        } else {
          const { json } = this.silderType;
          this.stateMatchineInterFace({
            data: {
              [json]: value,
              SvSt: 1
            }
          });
        }
      } catch (e) {
        e;
      }
    },
    onHide() {
      const json = this.TemUn ? this.silderType.json + 'D' : this.silderType.json;
      this.$refs.picker.setColumnValue(0, this[json]);
      this.SetPopup({ SvStPopup: false });
    },
    onCancel() {
      const json = this.TemUn ? this.silderType.json + 'D' : this.silderType.json;
      this.$refs.picker.setColumnValue(0, this[json]);
      this.SetPopup({ SvStPopup: false });
    }
  }
};
</script>

<style lang="scss">
.svst-picker {
  .gree-picker {
    .custom-picker__title {
      display: flex;
      align-items: center;
      justify-content: center;
      flex-direction: column;
      height: 180px;
      p {
        color: #404657;
        font-size: 50px;
        font-weight: bold;
      }
      small {
        color: #989898;
        font-size: 36px;
      }
    }
    .gree-picker__columns {
      .gree-picker__frame {
        &::before {
          content: '℃';
          position: absolute;
          top: 50%;
          left: 50%;
          transform: translate(-50%, -50%);
          margin-left: 64px;
          color: #77a7e0;
          font-size: 56px;
        }
      }
    }
  }
  .onSetTemF {
    .gree-picker__columns {
      .gree-picker__frame {
        &::before {
          color: #71acf1;
          content: '℉';
          position: absolute;
          top: 50%;
          left: 50%;
          transform: translate(-50%, -50%);
          margin-left: 64px;
          color: #77a7e0;
          font-size: 56px;
        }
      }
    }
  }
}
</style>
